==> spread-5.0.0.54-py3-none-any.whl: spread_dashboard/project/views.py <==
import os
import re
import shutil
import signal

from django.http import HttpResponse
from django.shortcuts import render, redirect

from . import forms, configs, bam


def config(request, file_name):
    if file_name == 'info':
        return render(request, 'project/info.html')
    i = re.search(r'(_\d+)+', file_name)
    args = []
    if i:
        args.append(i[0])
    if request.method == 'POST':
        args.append(request.POST)

    if file_name == 'common':
        form = forms.CommonForm
    elif file_name.startswith('dali'):
        form = forms.DaliManagerForm
    elif file_name.startswith('mercury'):
        form = forms.MercuryManagerForm
    elif file_name.startswith('lom'):
        form = forms.LomManagerForm
    elif file_name.startswith('rbus'):
        form = forms.CanAdapterForm
    elif file_name.startswith('tcp'):
        form = forms.TcpAdapterForm
    elif file_name == 'frontier':
        form = forms.FrontierForm
    elif file_name == 'projector':
        form = forms.ProjectorForm
    elif file_name == 'scheduler':
        form = forms.SchedulerForm
    elif file_name == 'scripter':
        form = forms.ScripterForm
    elif file_name == 'events_sqlite':
        form = forms.EventsSqliteForm
    elif file_name == 'lighting':
        form = forms.LightingEquipmentForm
    elif file_name == 'dashboard':
        form = forms.DashboardForm
    elif file_name == 'cycler':
        form = forms.CyclerForm
    else:
        return HttpResponse("Unknown file %s" % file_name)

    form = form.of(*args)

    if request.method == 'POST':
        if form.is_valid():
            if form.changed_data:
                form.save()
            return redirect(request.path.split(file_name)[0] + '#' + file_name)

    return render(request, 'project/config.html', dict(form=form, name=form.__class__.Meta.model.__name__))


def ctp(request):
    with open(configs.Projector.ctp_file, 'wb') as dest:
        dest.write(request.body)

    bam.Project.generate_configs()

    return redirect(request.path.split('ctp')[0])


def index(request):
    if bam.project.restarted:
        return render(request, 'project/redirector.html', dict(timeout=15))
    elif request.method == 'POST':
        if 'download' in request.POST:
            file = configs.Projector.ctp_file
            if os.path.exists(file):
                with open(file, 'rb') as fh:
                    response = HttpResponse(fh.read(), content_type="application/force-download")
                    response['Content-Disposition'] = 'inline; filename=' + os.path.basename(file)
                    return response
        elif 'ctp' in request.FILES:
            with open(configs.Projector.ctp_file, 'wb+') as dest:
                for chunk in request.FILES['ctp'].chunks():
                    dest.write(chunk)

            bam.Project.generate_configs()

        elif 'clear' in request.POST:
            if request.POST.get('clear_data', False):
                shutil.rmtree(os.path.join(configs.DUMP_PATH, str(bam.project.id)), ignore_errors=True)

                if os.path.exists(configs.Projector.ctp_file):
                    os.remove(configs.Projector.ctp_file)

            for file in os.listdir(configs.SV_PATH):
                if os.path.isfile(os.path.join(configs.SV_PATH, file)):
                    if file.startswith('spread') and not file.startswith('spread_' + configs.Dashboard.file):
                        os.remove(os.path.join(configs.SV_PATH, file))

            for file in os.listdir(configs.CONFIG_PATH):
                if os.path.isfile(os.path.join(configs.CONFIG_PATH, file)):
                    if not file.startswith(configs.Dashboard.file):
                        os.remove(os.path.join(configs.CONFIG_PATH, file))
                else:
                    shutil.rmtree(os.path.join(configs.CONFIG_PATH, file), ignore_errors=True)

            os.system('sudo supervisorctl reread')
            os.system('sudo supervisorctl update')
            os.system('sudo service mosquitto stop')
            mosquitto = configs.Projector().mosquittoDB
            if os.path.isdir(mosquitto):
                shutil.rmtree(mosquitto, ignore_errors=True)
            elif os.path.isfile(mosquitto):
                os.remove(mosquitto)
            os.system('sudo service mosquitto start')
            bam.Project.inited = False

        elif 'supervisor' in request.POST:
            services = request.POST.get('supervisor', '').split(',')
            if services:
                self_name = 'spread_%s' % configs.Dashboard.file
                if 'restart' in request.POST and '_%s' % configs.Dashboard.file in services:
                    bam.Project.inited = False
                    bam.Project.restarted = True
                if 'restart' in request.POST or 'stop' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.LightingEquipment.config_dest, configs.DaliManager.config_dest,
                                    configs.Common.config_dest, configs.TcpAdapter.config_dest,
                                    configs.EventsSqlite.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)
                    extras = ('spread_%s_%s' % (configs.LightingEquipment.config_dest, configs.LightingEquipment.file),)
                    for extra in extras:
                        if extra in arr:
                            arr.remove(extra)
                            arr.insert(0, extra)

                    if self_name in arr:
                        arr.remove(self_name)
                    if arr:
                        os.system('sudo supervisorctl stop %s' % ' '.join(arr))

                if 'restart' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.TcpAdapter.config_dest, configs.EventsSqlite.config_dest,
                                    configs.Common.config_dest, configs.LightingEquipment.config_dest,
                                    configs.DaliManager.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)

                    extras = ('spread_%s' % configs.Projector.file,)
                    for extra in extras:
                        if extra in arr:
                            arr.remove(extra)
                            arr.insert(0, extra)

                    if self_name in arr:
                        restart_dashboard = True
                        arr.remove(self_name)
                    else:
                        restart_dashboard = False

                    os.system('sudo supervisorctl reread')
                    if arr:
                        os.system('sudo supervisorctl start %s' % ' '.join(arr))
                    os.system('sudo supervisorctl update')
                    if restart_dashboard:
                        os.kill(os.getpid(), signal.SIGTERM)

        return redirect(request.path)

    return render(request, 'project/project.html', dict(tree=configs.Tree(), uncheckable=[configs.Common.file]))

==> spread-5.1.0.48-py3-none-any.whl: spread_dashboard/project/views.py <==
import os
import re
import shutil
import signal

from django.http import HttpResponse
from django.shortcuts import render, redirect

from . import forms, configs, bam


def config(request, file_name):
    if file_name == 'info':
        return render(request, 'project/info.html')
    i = re.search(r'(_\d+)+', file_name)
    args = []
    if i:
        args.append(i[0])
    if request.method == 'POST':
        args.append(request.POST)

    if file_name == 'common':
        form = forms.CommonForm
    elif file_name.startswith('dali'):
        form = forms.DaliManagerForm
    elif file_name.startswith('knx') and request.GET.get('dest', None) == configs.KnxManager.config_dest:
        form = forms.KnxManagerForm
    elif file_name.startswith('mercury'):
        form = forms.MercuryManagerForm
    elif file_name.startswith('lom'):
        form = forms.LomManagerForm
    elif file_name.startswith('rbus'):
        form = forms.CanAdapterForm
    elif file_name.startswith('knx') and request.GET.get('dest', None) == configs.KnxNetIpAdapter.config_dest:
        form = forms.KnxAdapterForm
    elif file_name.startswith('tcp'):
        form = forms.TcpAdapterForm
    elif file_name == 'frontier':
        form = forms.FrontierForm
    elif file_name == 'projector':
        form = forms.ProjectorForm
    elif file_name == 'scheduler':
        form = forms.SchedulerForm
    elif file_name == 'scripter':
        form = forms.ScripterForm
    elif file_name == 'events_sqlite':
        form = forms.EventsSqliteForm
    elif file_name == 'lighting':
        form = forms.LightingEquipmentForm
    elif file_name == 'dashboard':
        form = forms.DashboardForm
    elif file_name == 'cycler':
        form = forms.CyclerForm
    else:
        return HttpResponse("Unknown file %s" % file_name)

    form = form.of(*args)

    if request.method == 'POST':
        if form.is_valid():
            if form.changed_data:
                form.save()
            return redirect(request.path.split(file_name)[0] + '#' + form.Meta.model.config_dest + '_' + file_name)

    return render(request, 'project/config.html', dict(form=form, name=form.__class__.Meta.model.__name__))


def ctp(request):
    with open(configs.Projector.ctp_file, 'wb') as dest:
        dest.write(request.body)

    bam.Project.generate_configs()

    return redirect(request.path.split('ctp')[0])


def reread_ctp(request):
    try:
        forced = request.GET.get('forced', '').lower() == 'true'
        bam.Project.generate_configs(force=forced)
        if forced:
            return HttpResponse("Configs recreated\n")
        else:
            return HttpResponse("Configs updated\n")
    except BaseException as ex:
        return HttpResponse(str(ex) + "\n")


def ping(request):
    return HttpResponse("pong\n")


def index(request):
    if bam.project.restarted:
        return render(request, 'project/redirector.html', dict(timeout=15, href=request.path))
    elif request.method == 'POST':
        if 'download' in request.POST:
            file = configs.Projector.ctp_file
            if os.path.exists(file):
                with open(file, 'rb') as fh:
                    response = HttpResponse(fh.read(), content_type="application/force-download")
                    response['Content-Disposition'] = 'inline; filename=' + os.path.basename(file)
                    return response
        elif 'ctp' in request.FILES:
            with open(configs.Projector.ctp_file, 'wb+') as dest:
                for chunk in request.FILES['ctp'].chunks():
                    dest.write(chunk)

            bam.Project.generate_configs()

        elif 'clear' in request.POST:
            if request.POST.get('clear_data', False):
                shutil.rmtree(os.path.join(configs.DUMP_PATH, str(bam.project.id)), ignore_errors=True)

                if os.path.exists(configs.Projector.ctp_file):
                    os.remove(configs.Projector.ctp_file)

            for file in os.listdir(configs.SV_PATH):
                if os.path.isfile(os.path.join(configs.SV_PATH, file)):
                    if file.startswith('spread') and not file.startswith('spread_' + configs.Dashboard.file):
                        os.remove(os.path.join(configs.SV_PATH, file))

            for file in os.listdir(configs.CONFIG_PATH):
                if os.path.isfile(os.path.join(configs.CONFIG_PATH, file)):
                    if not file.startswith(configs.Dashboard.file):
                        os.remove(os.path.join(configs.CONFIG_PATH, file))
                else:
                    shutil.rmtree(os.path.join(configs.CONFIG_PATH, file), ignore_errors=True)

            os.system('sudo supervisorctl reread')
            os.system('sudo supervisorctl update')
            os.system('sudo service mosquitto stop')
            mosquitto = configs.Projector().mosquittoDB
            if os.path.isdir(mosquitto):
                shutil.rmtree(mosquitto, ignore_errors=True)
            elif os.path.isfile(mosquitto):
                os.remove(mosquitto)
            os.system('sudo service mosquitto start')
            bam.Project.inited = False

        elif 'supervisor' in request.POST:
            services = request.POST.get('supervisor', '').split(',')
            if services:
                self_name = 'spread_%s' % configs.Dashboard.file
                if 'restart' in request.POST and '_%s' % configs.Dashboard.file in services:
                    bam.Project.inited = False
                    bam.Project.restarted = True
                if 'restart' in request.POST or 'stop' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.LightingEquipment.config_dest, configs.DaliManager.config_dest,
                                    configs.Common.config_dest, configs.TcpAdapter.config_dest,
                                    configs.EventsSqlite.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)
                    extras = ('spread_%s_%s' % (configs.LightingEquipment.config_dest, configs.LightingEquipment.file),)
                    for extra in extras:
                        if extra in arr:
                            arr.remove(extra)
                            arr.insert(0, extra)

                    if self_name in arr:
                        arr.remove(self_name)
                    if arr:
                        os.system('sudo supervisorctl stop %s' % ' '.join(arr))

                if 'restart' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.TcpAdapter.config_dest, configs.EventsSqlite.config_dest,
                                    configs.Common.config_dest, configs.LightingEquipment.config_dest,
                                    configs.DaliManager.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)

                    extras = []
                    for extra in ('spread_%s' % configs.Projector.file,):
                        if extra in arr:
                            extras.append(extra)
                            arr.remove(extra)

                    if extras:
                        os.system('sudo supervisorctl start %s' % ' '.join(extras))

                    if self_name in arr:
                        restart_dashboard = True
                        arr.remove(self_name)
                    else:
                        restart_dashboard = False

                    os.system('sudo supervisorctl reread')
                    if arr:
                        os.system('sudo supervisorctl start %s' % ' '.join(arr))
                    os.system('sudo supervisorctl update')
                    if restart_dashboard:
                        os.kill(os.getpid(), signal.SIGTERM)

        return redirect(request.path)

    return render(request, 'project/project.html', dict(tree=configs.Tree(), uncheckable=[configs.Common.file]))
